summaryrefslogtreecommitdiffstats
path: root/src/network
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:24:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:24:30 -0600
commita830bf10b7d4ed2c83ffe68c0b22d7c4ba9860b0 (patch)
tree3910055c634e2ca44eacd2c892118634df9b3597 /src/network
parentb0b53cc84f215df9b9bcce77253a6b7a9d300986 (diff)
downloadqt3-a830bf10.tar.gz
qt3-a830bf10.zip
Rename additional global TQt functions
Diffstat (limited to 'src/network')
-rw-r--r--src/network/qdns.cpp124
-rw-r--r--src/network/qftp.cpp48
-rw-r--r--src/network/qhttp.cpp22
-rw-r--r--src/network/qnetwork.cpp4
-rw-r--r--src/network/qnetwork.h4
-rw-r--r--src/network/qserversocket.cpp2
-rw-r--r--src/network/qsocket.cpp56
-rw-r--r--src/network/qsocketdevice.cpp12
-rw-r--r--src/network/qsocketdevice_unix.cpp30
9 files changed, 151 insertions, 151 deletions
diff --git a/src/network/qdns.cpp b/src/network/qdns.cpp
index 3cc4d76..45937fe 100644
--- a/src/network/qdns.cpp
+++ b/src/network/qdns.cpp
@@ -411,7 +411,7 @@ void QDnsAnswer::parseA()
{
if ( next != pp + 4 ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %d bytes long IN A for %s",
+ tqDebug( "QDns: saw %d bytes long IN A for %s",
next - pp, label.ascii() );
#endif
return;
@@ -424,7 +424,7 @@ void QDnsAnswer::parseA()
( answer[pp+2] << 8 ) +
( answer[pp+3] ) );
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN A %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN A %s (ttl %d)", label.ascii(),
rr->address.toString().ascii(), ttl );
#endif
}
@@ -434,7 +434,7 @@ void QDnsAnswer::parseAaaa()
{
if ( next != pp + 16 ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %d bytes long IN Aaaa for %s",
+ tqDebug( "QDns: saw %d bytes long IN Aaaa for %s",
next - pp, label.ascii() );
#endif
return;
@@ -444,7 +444,7 @@ void QDnsAnswer::parseAaaa()
rr->t = QDns::Aaaa;
rr->address = QHostAddress( answer+pp );
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN Aaaa %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN Aaaa %s (ttl %d)", label.ascii(),
rr->address.toString().ascii(), ttl );
#endif
}
@@ -455,7 +455,7 @@ void QDnsAnswer::parseMx()
{
if ( next < pp + 2 ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %d bytes long IN MX for %s",
+ tqDebug( "QDns: saw %d bytes long IN MX for %s",
next - pp, label.ascii() );
#endif
return;
@@ -467,13 +467,13 @@ void QDnsAnswer::parseMx()
rr->target = readString().lower();
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad string in MX for %s", label.ascii() );
+ tqDebug( "QDns: saw bad string in MX for %s", label.ascii() );
#endif
return;
}
rr->t = QDns::Mx;
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN MX %d %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN MX %d %s (ttl %d)", label.ascii(),
rr->priority, rr->target.ascii(), ttl );
#endif
}
@@ -483,7 +483,7 @@ void QDnsAnswer::parseSrv()
{
if ( next < pp + 6 ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %d bytes long IN SRV for %s",
+ tqDebug( "QDns: saw %d bytes long IN SRV for %s",
next - pp, label.ascii() );
#endif
return;
@@ -497,13 +497,13 @@ void QDnsAnswer::parseSrv()
rr->target = readString().lower();
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad string in SRV for %s", label.ascii() );
+ tqDebug( "QDns: saw bad string in SRV for %s", label.ascii() );
#endif
return;
}
rr->t = QDns::Srv;
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN SRV %d %d %d %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN SRV %d %d %d %s (ttl %d)", label.ascii(),
rr->priority, rr->weight, rr->port, rr->target.ascii(), ttl );
#endif
}
@@ -514,7 +514,7 @@ void QDnsAnswer::parseCname()
QString target = readString().lower();
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad cname for for %s", label.ascii() );
+ tqDebug( "QDns: saw bad cname for for %s", label.ascii() );
#endif
return;
}
@@ -523,7 +523,7 @@ void QDnsAnswer::parseCname()
rr->t = QDns::Cname;
rr->target = target;
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN CNAME %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN CNAME %s (ttl %d)", label.ascii(),
rr->target.ascii(), ttl );
#endif
}
@@ -534,7 +534,7 @@ void QDnsAnswer::parseNs()
QString target = readString().lower();
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad cname for for %s", label.ascii() );
+ tqDebug( "QDns: saw bad cname for for %s", label.ascii() );
#endif
return;
}
@@ -542,7 +542,7 @@ void QDnsAnswer::parseNs()
// parse, but ignore
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN NS %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN NS %s (ttl %d)", label.ascii(),
target.ascii(), ttl );
#endif
}
@@ -553,7 +553,7 @@ void QDnsAnswer::parsePtr()
QString target = readString().lower();
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad PTR for for %s", label.ascii() );
+ tqDebug( "QDns: saw bad PTR for for %s", label.ascii() );
#endif
return;
}
@@ -562,7 +562,7 @@ void QDnsAnswer::parsePtr()
rr->t = QDns::Ptr;
rr->target = target;
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN PTR %s (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN PTR %s (ttl %d)", label.ascii(),
rr->target.ascii(), ttl );
#endif
}
@@ -573,7 +573,7 @@ void QDnsAnswer::parseTxt()
QString text = readString(FALSE);
if ( !ok ) {
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw bad TXT for for %s", label.ascii() );
+ tqDebug( "QDns: saw bad TXT for for %s", label.ascii() );
#endif
return;
}
@@ -582,7 +582,7 @@ void QDnsAnswer::parseTxt()
rr->t = QDns::Txt;
rr->text = text;
#if defined(QDNS_DEBUG)
- qDebug( "QDns: saw %s IN TXT \"%s\" (ttl %d)", label.ascii(),
+ tqDebug( "QDns: saw %s IN TXT \"%s\" (ttl %d)", label.ascii(),
rr->text.ascii(), ttl );
#endif
}
@@ -593,7 +593,7 @@ void QDnsAnswer::parse()
// okay, do the work...
if ( (answer[2] & 0x78) != 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: answer to wrong query type (%d)", answer[1] );
+ tqDebug( "DNS Manager: answer to wrong query type (%d)", answer[1] );
#endif
ok = FALSE;
return;
@@ -605,7 +605,7 @@ void QDnsAnswer::parse()
// TC
if ( (answer[2] & 2) != 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: truncated answer; pressing on" );
+ tqDebug( "DNS Manager: truncated answer; pressing on" );
#endif
}
@@ -617,7 +617,7 @@ void QDnsAnswer::parse()
if ( (answer[3] & 0x0f) == 3 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: saw NXDomain for %s", query->l.ascii() );
+ tqDebug( "DNS Manager: saw NXDomain for %s", query->l.ascii() );
#endif
// NXDomain. cache that for one minute.
rr = new QDnsRR( query->l );
@@ -632,7 +632,7 @@ void QDnsAnswer::parse()
if ( (answer[3] & 0x0f) != 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: error code %d", answer[3] & 0x0f );
+ tqDebug( "DNS Manager: error code %d", answer[3] & 0x0f );
#endif
ok = FALSE;
return;
@@ -671,7 +671,7 @@ void QDnsAnswer::parse()
rdlength = ( answer[pp+8] << 8 ) + answer[pp+9];
if ( pp + 10 + rdlength > size ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: ran out of stuff to parse (%d+%d>%d (%d)",
+ tqDebug( "DNS Manager: ran out of stuff to parse (%d+%d>%d (%d)",
pp, rdlength, size, rrno < ancount );
#endif
// if we're still in the AN section, we should go back and
@@ -689,7 +689,7 @@ void QDnsAnswer::parse()
pp = pp + 10;
if ( clas != 1 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: class %d (not internet) for %s",
+ tqDebug( "DNS Manager: class %d (not internet) for %s",
clas, label.isNull() ? "." : label.ascii() );
#endif
} else {
@@ -723,7 +723,7 @@ void QDnsAnswer::parse()
default:
// something we don't know
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: type %d for %s", type,
+ tqDebug( "DNS Manager: type %d for %s", type,
label.isNull() ? "." : label.ascii() );
#endif
break;
@@ -750,7 +750,7 @@ void QDnsAnswer::parse()
}
if ( answers == 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: answer contained no answers" );
+ tqDebug( "DNS Manager: answer contained no answers" );
#endif
ok = ( aa && rd );
}
@@ -790,7 +790,7 @@ void QDnsAnswer::parse()
// well, it's equal, but it's not the same. so we kill it,
// but use its expiry time.
#if defined(QDNS_DEBUG)
- qDebug( "killing off old %d for %s, expire was %d",
+ tqDebug( "killing off old %d for %s, expire was %d",
older->t, older->domain->name().latin1(),
rr->expireTime );
#endif
@@ -799,7 +799,7 @@ void QDnsAnswer::parse()
rr->deleteTime = QMAX( older->deleteTime, rr->deleteTime );
older->deleteTime = 0;
#if defined(QDNS_DEBUG)
- qDebug( " adjusted expire is %d", rr->expireTime );
+ tqDebug( " adjusted expire is %d", rr->expireTime );
#endif
}
drrs->next();
@@ -808,7 +808,7 @@ void QDnsAnswer::parse()
}
#if defined(QDNS_DEBUG)
- //qDebug( "DNS Manager: ()" );
+ //tqDebug( "DNS Manager: ()" );
#endif
}
@@ -836,7 +836,7 @@ void QDnsAnswer::notify()
notified.insert( (void*)dns, (void*)42 );
if ( rrs->count() == 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: found no answers!" );
+ tqDebug( "DNS Manager: found no answers!" );
#endif
dns->d->noNames = TRUE;
((QDnsUgleHack*)dns)->ugle( TRUE );
@@ -846,7 +846,7 @@ void QDnsAnswer::notify()
((QDnsUgleHack*)dns)->ugle();
#if defined(QDNS_DEBUG)
else
- qDebug( "DNS Manager: DNS thing %s not notified for %s",
+ tqDebug( "DNS Manager: DNS thing %s not notified for %s",
dns->label().ascii(), query->l.ascii() );
#endif
}
@@ -902,7 +902,7 @@ static void cleanupDns()
QDnsManager * QDnsManager::manager()
{
if ( !globalManager ) {
- qAddPostRoutine(cleanupDns);
+ tqAddPostRoutine(cleanupDns);
new QDnsManager();
}
return globalManager;
@@ -913,7 +913,7 @@ void QDnsUgleHack::ugle( bool emitAnyway)
{
if ( emitAnyway || !isWorking() ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: status change for %s (type %d)",
+ tqDebug( "DNS Manager: status change for %s (type %d)",
label().ascii(), recordType() );
#endif
emit resultsReady();
@@ -977,9 +977,9 @@ QDnsManager::QDnsManager()
if ( !ns->current() ) {
ns->append( new QHostAddress(*h) );
#if defined(QDNS_DEBUG)
- qDebug( "using name server %s", h->toString().latin1() );
+ tqDebug( "using name server %s", h->toString().latin1() );
} else {
- qDebug( "skipping address %s", h->toString().latin1() );
+ tqDebug( "skipping address %s", h->toString().latin1() );
#endif
}
::ns->next();
@@ -1000,9 +1000,9 @@ QDnsManager::QDnsManager()
if ( !domains->current() ) {
domains->append( s );
#if defined(QDNS_DEBUG)
- qDebug( "searching domain %s", s );
+ tqDebug( "searching domain %s", s );
} else {
- qDebug( "skipping domain %s", s );
+ tqDebug( "skipping domain %s", s );
#endif
}
::domains->next();
@@ -1035,7 +1035,7 @@ void QDnsManager::cleanCache()
QDnsDomain * d;
Q_UINT32 thisSweep = now();
#if defined(QDNS_DEBUG)
- qDebug( "QDnsManager::cleanCache(: Called, time is %u, last was %u",
+ tqDebug( "QDnsManager::cleanCache(: Called, time is %u, last was %u",
thisSweep, lastSweep );
#endif
@@ -1079,12 +1079,12 @@ void QDnsManager::answer()
#endif
#if defined(QDNS_DEBUG)
#if !defined (QT_NO_IPV6)
- qDebug("DNS Manager: answer arrived: %d bytes from %s:%d", r,
+ tqDebug("DNS Manager: answer arrived: %d bytes from %s:%d", r,
useIpv4Socket ? ipv4Socket->peerAddress().toString().ascii()
: ipv6Socket->peerAddress().toString().ascii(),
useIpv4Socket ? ipv4Socket->peerPort() : ipv6Socket->peerPort() );
#else
- qDebug("DNS Manager: answer arrived: %d bytes from %s:%d", r,
+ tqDebug("DNS Manager: answer arrived: %d bytes from %s:%d", r,
ipv4Socket->peerAddress().toString().ascii(), ipv4Socket->peerPort());;
#endif
#endif
@@ -1101,7 +1101,7 @@ void QDnsManager::answer()
i++;
if ( i == queries.size() ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: bad id (0x%04x) %d", aid, i );
+ tqDebug( "DNS Manager: bad id (0x%04x) %d", aid, i );
#endif
return;
}
@@ -1110,7 +1110,7 @@ void QDnsManager::answer()
if ( ( (Q_UINT8)(a[2]) & 0x80 ) == 0 ) {
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: received a query" );
+ tqDebug( "DNS Manager: received a query" );
#endif
return;
}
@@ -1159,7 +1159,7 @@ void QDnsManager::transmitQuery( int i )
// and then get rid of the query
queries.take( i );
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: giving up on query 0x%04x", q->id );
+ tqDebug( "DNS Manager: giving up on query 0x%04x", q->id );
#endif
delete q;
QTimer::singleShot( 0, QDnsManager::manager(), SLOT(cleanCache()) );
@@ -1255,7 +1255,7 @@ void QDnsManager::transmitQuery( int i )
// and then get rid of the query
queries.take( i );
#if defined(QDNS_DEBUG)
- qDebug( "DNS Manager: no DNS server found on query 0x%04x", q->id );
+ tqDebug( "DNS Manager: no DNS server found on query 0x%04x", q->id );
#endif
delete q;
QTimer::singleShot( 1000*10, QDnsManager::manager(), SLOT(cleanCache()) );
@@ -1271,7 +1271,7 @@ void QDnsManager::transmitQuery( int i )
ipv6Socket->writeBlock( p.data(), pp, receiver, 53 );
#endif
#if defined(QDNS_DEBUG)
- qDebug( "issuing query 0x%04x (%d) about %s type %d to %s",
+ tqDebug( "issuing query 0x%04x (%d) about %s type %d to %s",
q->id, q->step, q->l.ascii(), q->t,
ns->at( q->step % ns->count() )->toString().ascii() );
#endif
@@ -1289,7 +1289,7 @@ void QDnsManager::transmitQuery( int i )
ipv6Socket->writeBlock( p.data(), pp, *server, 53 );
#endif
#if defined(QDNS_DEBUG)
- qDebug( "copying query to %s", server->toString().ascii() );
+ tqDebug( "copying query to %s", server->toString().ascii() );
#endif
}
}
@@ -1408,12 +1408,12 @@ QPtrList<QDnsRR> * QDnsDomain::cached( const QDns * r )
QString s = *it++;
nxdomain = FALSE;
#if defined(QDNS_DEBUG)
- qDebug( "looking at cache for %s (%s %d)",
+ tqDebug( "looking at cache for %s (%s %d)",
s.ascii(), r->label().ascii(), r->recordType() );
#endif
QDnsDomain * d = m->domain( s );
#if defined(QDNS_DEBUG)
- qDebug( " - found %d RRs", d && d->rrs ? d->rrs->count() : 0 );
+ tqDebug( " - found %d RRs", d && d->rrs ? d->rrs->count() : 0 );
#endif
if ( d->rrs )
d->rrs->first();
@@ -1425,7 +1425,7 @@ QPtrList<QDnsRR> * QDnsDomain::cached( const QDns * r )
// cname. if the code is ugly, that may just
// possibly be because the concept is.
#if defined(QDNS_DEBUG)
- qDebug( "found cname from %s to %s",
+ tqDebug( "found cname from %s to %s",
r->label().ascii(), rr->target.ascii() );
#endif
s = rr->target;
@@ -1472,11 +1472,11 @@ QPtrList<QDnsRR> * QDnsDomain::cached( const QDns * r )
// if we found a positive result, return quickly
if ( answer && l->count() ) {
#if defined(QDNS_DEBUG)
- qDebug( "found %d records for %s",
+ tqDebug( "found %d records for %s",
l->count(), r->label().ascii() );
l->first();
while( l->current() ) {
- qDebug( " type %d target %s address %s",
+ tqDebug( " type %d target %s address %s",
l->current()->t,
l->current()->target.latin1(),
l->current()->address.toString().latin1() );
@@ -1489,7 +1489,7 @@ QPtrList<QDnsRR> * QDnsDomain::cached( const QDns * r )
#if defined(QDNS_DEBUG)
if ( nxdomain )
- qDebug( "found NXDomain %s", s.ascii() );
+ tqDebug( "found NXDomain %s", s.ascii() );
#endif
if ( !nxdomain ) {
@@ -1539,7 +1539,7 @@ void QDnsDomain::sweep( Q_UINT32 thisSweep )
rr->deleteTime = thisSweep; // will hit next time around
#if defined(QDNS_DEBUG)
- qDebug( "QDns::sweep: %s type %d expires %u %u - %s / %s",
+ tqDebug( "QDns::sweep: %s type %d expires %u %u - %s / %s",
rr->domain->name().latin1(), rr->t,
rr->expireTime, rr->deleteTime,
rr->target.latin1(), rr->address.toString().latin1());
@@ -1775,10 +1775,10 @@ void QDns::setLabel( const QString & label )
setStartQueryTimer(); // start query the next time we enter event loop
#endif
#if defined(QDNS_DEBUG)
- qDebug( "QDns::setLabel: %d address(es) for %s", n.count(), l.ascii() );
+ tqDebug( "QDns::setLabel: %d address(es) for %s", n.count(), l.ascii() );
int i = 0;
for( i = 0; i < (int)n.count(); i++ )
- qDebug( "QDns::setLabel: %d: %s", i, n[i].ascii() );
+ tqDebug( "QDns::setLabel: %d: %s", i, n[i].ascii() );
#endif
}
@@ -1965,7 +1965,7 @@ QString QDns::toInAddrArpaDomain( const QHostAddress &address )
bool QDns::isWorking() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::isWorking (%s, %d)", l.ascii(), t );
+ tqDebug( "QDns::isWorking (%s, %d)", l.ascii(), t );
#endif
if ( t == None )
return FALSE;
@@ -2020,7 +2020,7 @@ bool QDns::isWorking() const
QValueList<QHostAddress> QDns::addresses() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::addresses (%s)", l.ascii() );
+ tqDebug( "QDns::addresses (%s)", l.ascii() );
#endif
QValueList<QHostAddress> result;
if ( t != A && t != Aaaa )
@@ -2074,7 +2074,7 @@ QValueList<QHostAddress> QDns::addresses() const
QValueList<QDns::MailServer> QDns::mailServers() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::mailServers (%s)", l.ascii() );
+ tqDebug( "QDns::mailServers (%s)", l.ascii() );
#endif
QValueList<QDns::MailServer> result;
if ( t != Mx )
@@ -2131,7 +2131,7 @@ QValueList<QDns::MailServer> QDns::mailServers() const
QValueList<QDns::Server> QDns::servers() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::servers (%s)", l.ascii() );
+ tqDebug( "QDns::servers (%s)", l.ascii() );
#endif
QValueList<QDns::Server> result;
if ( t != Srv )
@@ -2170,7 +2170,7 @@ QValueList<QDns::Server> QDns::servers() const
QStringList QDns::hostNames() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::hostNames (%s)", l.ascii() );
+ tqDebug( "QDns::hostNames (%s)", l.ascii() );
#endif
QStringList result;
if ( t != Ptr )
@@ -2208,7 +2208,7 @@ QStringList QDns::hostNames() const
QStringList QDns::texts() const
{
#if defined(QDNS_DEBUG)
- qDebug( "QDns::texts (%s)", l.ascii() );
+ tqDebug( "QDns::texts (%s)", l.ascii() );
#endif
QStringList result;
if ( t != Txt )
@@ -2475,7 +2475,7 @@ void QDns::doResInit()
last = searchList.find( separator, first );
if ( last < 0 )
last = searchList.length();
- domains->append( qstrdup( searchList.mid( first, last-first ) ) );
+ domains->append( tqstrdup( searchList.mid( first, last-first ) ) );
first = last+1;
} while( first < (int)searchList.length() );
}
diff --git a/src/network/qftp.cpp b/src/network/qftp.cpp
index 0183a7a..55db3bd 100644
--- a/src/network/qftp.cpp
+++ b/src/network/qftp.cpp
@@ -325,7 +325,7 @@ void QFtpDTP::writeData()
{
if ( is_ba ) {
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::writeData: write %d bytes", data.ba->size() );
+ tqDebug( "QFtpDTP::writeData: write %d bytes", data.ba->size() );
#endif
if ( data.ba->size() == 0 )
emit dataTransferProgress( 0, bytesTotal );
@@ -340,7 +340,7 @@ void QFtpDTP::writeData()
while ( !data.dev->atEnd() && socket.bytesToWrite()==0 ) {
Q_LONG read = data.dev->readBlock( buf, blockSize );
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::writeData: writeBlock() of size %d bytes", (int)read );
+ tqDebug( "QFtpDTP::writeData: writeBlock() of size %d bytes", (int)read );
#endif
socket.writeBlock( buf, read );
if ( !data.dev )
@@ -375,7 +375,7 @@ inline void QFtpDTP::clearError()
void QFtpDTP::abortConnection()
{
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::abortConnection" );
+ tqDebug( "QFtpDTP::abortConnection" );
#endif
callWriteData = FALSE;
clearData();
@@ -526,7 +526,7 @@ void QFtpDTP::socketConnected()
bytesDone = 0;
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::connectState( CsConnected )" );
+ tqDebug( "QFtpDTP::connectState( CsConnected )" );
#endif
emit connectState( QFtpDTP::CsConnected );
}
@@ -536,7 +536,7 @@ void QFtpDTP::socketReadyRead()
if ( pi->currentCommand().isEmpty() ) {
socket.close();
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::connectState( CsClosed )" );
+ tqDebug( "QFtpDTP::connectState( CsClosed )" );
#endif
emit connectState( QFtpDTP::CsClosed );
return;
@@ -547,7 +547,7 @@ void QFtpDTP::socketReadyRead()
QUrlInfo i;
QString line = socket.readLine();
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP read (list): '%s'", line.latin1() );
+ tqDebug( "QFtpDTP read (list): '%s'", line.latin1() );
#endif
if ( parseDir( line, "", &i ) ) {
emit listInfo( i );
@@ -570,14 +570,14 @@ void QFtpDTP::socketReadyRead()
ba.resize( bytesRead );
bytesDone += bytesRead;
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP read: %d bytes (total %d bytes)", (int)bytesRead, bytesDone );
+ tqDebug( "QFtpDTP read: %d bytes (total %d bytes)", (int)bytesRead, bytesDone );
#endif
emit dataTransferProgress( bytesDone, bytesTotal );
if (data.dev) // make sure it wasn't deleted in the slot
data.dev->writeBlock( ba );
} else {
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP readyRead: %d bytes available (total %d bytes read)", (int)bytesAvailable(), bytesDone );
+ tqDebug( "QFtpDTP readyRead: %d bytes available (total %d bytes read)", (int)bytesAvailable(), bytesDone );
#endif
emit dataTransferProgress( bytesDone+socket.bytesAvailable(), bytesTotal );
emit readyRead();
@@ -589,12 +589,12 @@ void QFtpDTP::socketError( int e )
{
if ( e == QSocket::ErrHostNotFound ) {
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::connectState( CsHostNotFound )" );
+ tqDebug( "QFtpDTP::connectState( CsHostNotFound )" );
#endif
emit connectState( QFtpDTP::CsHostNotFound );
} else if ( e == QSocket::ErrConnectionRefused ) {
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::connectState( CsConnectionRefused )" );
+ tqDebug( "QFtpDTP::connectState( CsConnectionRefused )" );
#endif
emit connectState( QFtpDTP::CsConnectionRefused );
}
@@ -606,7 +606,7 @@ void QFtpDTP::socketConnectionClosed()
clearData();
}
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::connectState( CsClosed )" );
+ tqDebug( "QFtpDTP::connectState( CsClosed )" );
#endif
emit connectState( QFtpDTP::CsClosed );
}
@@ -615,7 +615,7 @@ void QFtpDTP::socketBytesWritten( int bytes )
{
bytesDone += bytes;
#if defined(QFTPDTP_DEBUG)
- qDebug( "QFtpDTP::bytesWritten( %d )", bytesDone );
+ tqDebug( "QFtpDTP::bytesWritten( %d )", bytesDone );
#endif
emit dataTransferProgress( bytesDone, bytesTotal );
if ( callWriteData )
@@ -701,7 +701,7 @@ void QFtpPI::abort()
abortState = AbortStarted;
#if defined(QFTPPI_DEBUG)
- qDebug( "QFtpPI send: ABOR" );
+ tqDebug( "QFtpPI send: ABOR" );
#endif
commandSocket.writeBlock( "ABOR\r\n", 6 );
@@ -718,7 +718,7 @@ void QFtpPI::connected()
{
state = Begin;
#if defined(QFTPPI_DEBUG)
-// qDebug( "QFtpPI state: %d [connected()]", state );
+// tqDebug( "QFtpPI state: %d [connected()]", state );
#endif
emit connectState( QFtp::Connected );
}
@@ -807,11 +807,11 @@ void QFtpPI::readyRead()
bool QFtpPI::processReply()
{
#if defined(QFTPPI_DEBUG)
-// qDebug( "QFtpPI state: %d [processReply() begin]", state );
+// tqDebug( "QFtpPI state: %d [processReply() begin]", state );
if ( replyText.length() < 400 )
- qDebug( "QFtpPI recv: %d %s", 100*replyCode[0]+10*replyCode[1]+replyCode[2], replyText.latin1() );
+ tqDebug( "QFtpPI recv: %d %s", 100*replyCode[0]+10*replyCode[1]+replyCode[2], replyText.latin1() );
else
- qDebug( "QFtpPI recv: %d (text skipped)", 100*replyCode[0]+10*replyCode[1]+replyCode[2] );
+ tqDebug( "QFtpPI recv: %d (text skipped)", 100*replyCode[0]+10*replyCode[1]+replyCode[2] );
#endif
// process 226 replies ("Closing Data Connection") only when the data
@@ -861,7 +861,7 @@ bool QFtpPI::processReply()
return TRUE;
}
#if defined(QFTPPI_DEBUG)
-// qDebug( "QFtpPI state: %d [processReply() intermediate]", state );
+// tqDebug( "QFtpPI state: %d [processReply() intermediate]", state );
#endif
// special actions on certain replies
@@ -878,7 +878,7 @@ bool QFtpPI::processReply()
QRegExp addrPortPattern("(\\d+),(\\d+),(\\d+),(\\d+),(\\d+),(\\d+)");
if (addrPortPattern.search(replyText) == -1) {
#if defined(QFTPPI_DEBUG)
- qDebug( "QFtp: bad 227 response -- address and port information missing" );
+ tqDebug( "QFtp: bad 227 response -- address and port information missing" );
#endif
// ### error handling
} else {
@@ -930,7 +930,7 @@ bool QFtpPI::processReply()
break;
}
#if defined(QFTPPI_DEBUG)
-// qDebug( "QFtpPI state: %d [processReply() end]", state );
+// tqDebug( "QFtpPI state: %d [processReply() end]", state );
#endif
return TRUE;
}
@@ -951,7 +951,7 @@ bool QFtpPI::startNextCmd()
#if defined(QFTPPI_DEBUG)
if ( state != Idle )
- qDebug( "QFtpPI startNextCmd: Internal error! QFtpPI called in non-Idle state %d", state );
+ tqDebug( "QFtpPI startNextCmd: Internal error! QFtpPI called in non-Idle state %d", state );
#endif
if ( pendingCommands.isEmpty() ) {
currentCmd = QString::null;
@@ -961,7 +961,7 @@ bool QFtpPI::startNextCmd()
currentCmd = pendingCommands.first();
pendingCommands.pop_front();
#if defined(QFTPPI_DEBUG)
- qDebug( "QFtpPI send: %s", currentCmd.left( currentCmd.length()-2 ).latin1() );
+ tqDebug( "QFtpPI send: %s", currentCmd.left( currentCmd.length()-2 ).latin1() );
#endif
state = Waiting;
#ifndef QT_NO_TEXTCODEC
@@ -1042,7 +1042,7 @@ static QFtpPrivate* d( const QFtp* foo )
if ( !d_ptr ) {
d_ptr = new QPtrDict<QFtpPrivate>;
d_ptr->setAutoDelete( TRUE );
- qAddPostRoutine( cleanup_d_ptr );
+ tqAddPostRoutine( cleanup_d_ptr );
}
QFtpPrivate* ret = d_ptr->find( (void*)foo );
if ( ! ret ) {
@@ -1093,7 +1093,7 @@ static void delete_d( const QFtp* foo )
\endcode
This code will only work if the QFtp class is registered; to
- register the class, you must call qInitNetworkProtocols() before
+ register the class, you must call tqInitNetworkProtocols() before
using a QUrlOperator with QFtp.
The rest of this descrption describes the direct interface to FTP.
diff --git a/src/network/qhttp.cpp b/src/network/qhttp.cpp
index b0a7ff5..f5a77d7 100644
--- a/src/network/qhttp.cpp
+++ b/src/network/qhttp.cpp
@@ -1039,7 +1039,7 @@ QString QHttpRequestHeader::toString() const
\endcode
This code will only work if the QHttp class is registered; to
- register the class, you must call qInitNetworkProtocols() before
+ register the class, you must call tqInitNetworkProtocols() before
using a QUrlOperator with HTTP.
The QNetworkProtocol interface for HTTP only supports the
@@ -1435,7 +1435,7 @@ void QHttp::abort()
Q_ULONG QHttp::bytesAvailable() const
{
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp::bytesAvailable(): %d bytes", (int)d->rba.size() );
+ tqDebug( "QHttp::bytesAvailable(): %d bytes", (int)d->rba.size() );
#endif
return d->rba.size();
}
@@ -1450,7 +1450,7 @@ Q_LONG QHttp::readBlock( char *data, Q_ULONG maxlen )
{
if ( data == 0 && maxlen != 0 ) {
#if defined(QT_CHECK_NULL)
- qWarning( "QHttp::readBlock: Null pointer error" );
+ tqWarning( "QHttp::readBlock: Null pointer error" );
#endif
return -1;
}
@@ -1460,7 +1460,7 @@ Q_LONG QHttp::readBlock( char *data, Q_ULONG maxlen )
d->bytesDone += maxlen;
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp::readBlock(): read %d bytes (%d bytes done)", (int)maxlen, d->bytesDone );
+ tqDebug( "QHttp::readBlock(): read %d bytes (%d bytes done)", (int)maxlen, d->bytesDone );
#endif
return maxlen;
}
@@ -1880,7 +1880,7 @@ void QHttp::slotConnected()
d->bytesTotal = str.length();
d->socket.writeBlock( str.latin1(), d->bytesTotal );
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp: write request header:\n---{\n%s}---", str.latin1() );
+ tqDebug( "QHttp: write request header:\n---{\n%s}---", str.latin1() );
#endif
if ( d->postDevice ) {
@@ -1927,7 +1927,7 @@ void QHttp::slotBytesWritten( int written )
int n = d->postDevice->readBlock( arr.data(), max );
if ( n != max ) {
- qWarning("Could not read enough bytes from the device");
+ tqWarning("Could not read enough bytes from the device");
close();
return;
}
@@ -1965,12 +1965,12 @@ void QHttp::slotReadyRead()
return;
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp: read response header:\n---{\n%s}---", d->headerStr.latin1() );
+ tqDebug( "QHttp: read response header:\n---{\n%s}---", d->headerStr.latin1() );
#endif
d->response = QHttpResponseHeader( d->headerStr );
d->headerStr = "";
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp: read response header:\n---{\n%s}---", d->response.toString().latin1() );
+ tqDebug( "QHttp: read response header:\n---{\n%s}---", d->response.toString().latin1() );
#endif
// Check header
if ( !d->response.isValid() ) {
@@ -2089,7 +2089,7 @@ void QHttp::slotReadyRead()
delete arr;
d->bytesDone += n;
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp::slotReadyRead(): read %ld bytes (%d bytes done)", n, d->bytesDone );
+ tqDebug( "QHttp::slotReadyRead(): read %ld bytes (%d bytes done)", n, d->bytesDone );
#endif
if ( d->response.hasContentLength() )
emit dataReadProgress( d->bytesDone, d->response.contentLength() );
@@ -2098,7 +2098,7 @@ void QHttp::slotReadyRead()
} else {
d->rba.append( arr );
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp::slotReadyRead(): read %ld bytes (%ld bytes done)", n, d->bytesDone + bytesAvailable() );
+ tqDebug( "QHttp::slotReadyRead(): read %ld bytes (%ld bytes done)", n, d->bytesDone + bytesAvailable() );
#endif
if ( d->response.hasContentLength() )
emit dataReadProgress( d->bytesDone + bytesAvailable(), d->response.contentLength() );
@@ -2185,7 +2185,7 @@ void QHttp::killIdleTimer()
void QHttp::setState( int s )
{
#if defined(QHTTP_DEBUG)
- qDebug( "QHttp state changed %d -> %d", d->state, s );
+ tqDebug( "QHttp state changed %d -> %d", d->state, s );
#endif
d->state = (State)s;
emit stateChanged( s );
diff --git a/src/network/qserversocket.cpp b/src/network/qserversocket.cpp
index 3b3add9..e307c9b 100644
--- a/src/network/qserversocket.cpp
+++ b/src/network/qserversocket.cpp
@@ -176,7 +176,7 @@ void QServerSocket::init( const QHostAddress & address, Q_UINT16 port, int backl
connect( d->n, SIGNAL(activated(int)),
this, SLOT(incomingConnection(int)) );
} else {
- qWarning( "QServerSocket: failed to bind or listen to the socket" );
+ tqWarning( "QServerSocket: failed to bind or listen to the socket" );
delete d->s;
d->s = 0;
}
diff --git a/src/network/qsocket.cpp b/src/network/qsocket.cpp
index 492bc72..9414d0e 100644
--- a/src/network/qsocket.cpp
+++ b/src/network/qsocket.cpp
@@ -321,7 +321,7 @@ QSocket::QSocket( QObject *parent, const char *name )
QSocket::~QSocket()
{
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): Destroy", name() );
+ tqDebug( "QSocket (%s): Destroy", name() );
#endif
if ( state() != Idle )
close();
@@ -411,7 +411,7 @@ QSocket::State QSocket::state() const
void QSocket::connectToHost( const QString &host, Q_UINT16 port )
{
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::connectToHost: host %s, port %d",
+ tqDebug( "QSocket (%s)::connectToHost: host %s, port %d",
name(), host.ascii(), port );
#endif
setSocketIntern( -1 );
@@ -442,7 +442,7 @@ void QSocket::connectToHost( const QString &host, Q_UINT16 port )
void QSocket::tryConnecting()
{
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::tryConnecting()", name() );
+ tqDebug( "QSocket (%s)::tryConnecting()", name() );
#endif
// ### this ifdef isn't correct - addresses() also does /etc/hosts and
// numeric-address-as-string handling.
@@ -452,7 +452,7 @@ void QSocket::tryConnecting()
d->l4 = d->dns4->addresses();
if ( !d->l4.isEmpty() || !d->dns4->isWorking() ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::tryConnecting: host %s, port %d: "
+ tqDebug( "QSocket (%s)::tryConnecting: host %s, port %d: "
"%d IPv4 addresses",
name(), d->host.ascii(), d->port, d->l4.count() );
#endif
@@ -465,7 +465,7 @@ void QSocket::tryConnecting()
d->l6 = d->dns6->addresses();
if ( !d->l6.isEmpty() || !d->dns6->isWorking() ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::tryConnecting: host %s, port %d: "
+ tqDebug( "QSocket (%s)::tryConnecting: host %s, port %d: "
"%d IPv6 addresses",
name(), d->host.ascii(), d->port, d->l6.count() );
#endif
@@ -516,7 +516,7 @@ void QSocket::tryConnecting()
}
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::tryConnecting: "
+ tqDebug( "QSocket (%s)::tryConnecting: "
"Gave up on IP address %s",
name(), d->socket->peerAddress().toString().ascii() );
#endif
@@ -539,7 +539,7 @@ void QSocket::tryConnecting()
d->setSocketDevice( this, 0 );
stuck = TRUE;
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s)::tryConnecting: Trying IP address %s",
+ tqDebug( "QSocket (%s)::tryConnecting: Trying IP address %s",
name(), d->addr.toString().ascii() );
#endif
}
@@ -654,7 +654,7 @@ bool QSocket::open( int m )
{
if ( isOpen() ) {
#if defined(QT_CHECK_STATE)
- qWarning( "QSocket::open: Already open" );
+ tqWarning( "QSocket::open: Already open" );
#endif
return FALSE;
}
@@ -692,7 +692,7 @@ void QSocket::close()
if ( !d->rsn || !d->wsn )
return;
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): close socket", name() );
+ tqDebug( "QSocket (%s): close socket", name() );
#endif
if ( d->socket && d->wsize ) { // there's data to be written
d->state = Closing;
@@ -721,7 +721,7 @@ bool QSocket::consumeWriteBuf( Q_ULONG nbytes )
if ( nbytes <= 0 || nbytes > d->wsize )
return FALSE;
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): skipWriteBuf %d bytes", name(), (int)nbytes );
+ tqDebug( "QSocket (%s): skipWriteBuf %d bytes", name(), (int)nbytes );
#endif
d->wsize -= nbytes;
for ( ;; ) {
@@ -754,7 +754,7 @@ void QSocket::flush()
int consumed = 0;
while ( !osBufferFull && d->state >= Connecting && d->wsize > 0 ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): flush: Write data to the socket", name() );
+ tqDebug( "QSocket (%s): flush: Write data to the socket", name() );
#endif
QByteArray *a = d->wba.first();
int nwritten;
@@ -798,14 +798,14 @@ void QSocket::flush()
}
if ( consumed > 0 ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): flush: wrote %d bytes, %d left",
+ tqDebug( "QSocket (%s): flush: wrote %d bytes, %d left",
name(), consumed, (int)d->wsize );
#endif
emit bytesWritten( consumed );
}
if ( d->state == Closing && d->wsize == 0 ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): flush: Delayed close done. Terminating.",
+ tqDebug( "QSocket (%s): flush: Delayed close done. Terminating.",
name() );
#endif
setFlags( IO_Sequential );
@@ -981,20 +981,20 @@ Q_LONG QSocket::readBlock( char *data, Q_ULONG maxlen )
{
if ( data == 0 && maxlen != 0 ) {
#if defined(QT_CHECK_NULL)
- qWarning( "QSocket::readBlock: Null pointer error" );
+ tqWarning( "QSocket::readBlock: Null pointer error" );
#endif
return -1;
}
if ( !isOpen() ) {
#if defined(QT_CHECK_STATE)
- qWarning( "QSocket::readBlock: Socket is not open" );
+ tqWarning( "QSocket::readBlock: Socket is not open" );
#endif
return -1;
}
if ( maxlen >= d->rba.size() )
maxlen = d->rba.size();
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): readBlock %d bytes", name(), (int)maxlen );
+ tqDebug( "QSocket (%s): readBlock %d bytes", name(), (int)maxlen );
#endif
d->rba.consumeBytes( maxlen, data );
// After we read data from our internal buffer, if we use the
@@ -1019,18 +1019,18 @@ Q_LONG QSocket::writeBlock( const char *data, Q_ULONG len )
{
#if defined(QT_CHECK_NULL)
if ( data == 0 && len != 0 ) {
- qWarning( "QSocket::writeBlock: Null pointer error" );
+ tqWarning( "QSocket::writeBlock: Null pointer error" );
}
#endif
#if defined(QT_CHECK_STATE)
if ( !isOpen() ) {
- qWarning( "QSocket::writeBlock: Socket is not open" );
+ tqWarning( "QSocket::writeBlock: Socket is not open" );
return -1;
}
#endif
#if defined(QT_CHECK_STATE)
if ( d->state == Closing ) {
- qWarning( "QSocket::writeBlock: Cannot write, socket is closing" );
+ tqWarning( "QSocket::writeBlock: Cannot write, socket is closing" );
}
#endif
if ( len == 0 || d->state == Closing || d->state == Idle )
@@ -1061,7 +1061,7 @@ Q_LONG QSocket::writeBlock( const char *data, Q_ULONG len )
else if ( d->wsn )
d->wsn->setEnabled( TRUE );
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): writeBlock %d bytes", name(), (int)len );
+ tqDebug( "QSocket (%s): writeBlock %d bytes", name(), (int)len );
#endif
return len;
}
@@ -1121,7 +1121,7 @@ int QSocket::ungetch( int ch )
{
#if defined(QT_CHECK_STATE)
if ( !isOpen() ) {
- qWarning( "QSocket::ungetch: Socket not open" );
+ tqWarning( "QSocket::ungetch: Socket not open" );
return -1;
}
#endif
@@ -1243,7 +1243,7 @@ void QSocket::sn_read( bool force )
if ( nread == 0 ) { // really closed
if ( !d->socket->isOpen() ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): sn_read: Connection closed", name() );
+ tqDebug( "QSocket (%s): sn_read: Connection closed", name() );
#endif
d->connectionClosed();
emit connectionClosed();
@@ -1258,7 +1258,7 @@ void QSocket::sn_read( bool force )
return;
}
#if defined(QSOCKET_DEBUG)
- qWarning( "QSocket::sn_read (%s): Close error", name() );
+ tqWarning( "QSocket::sn_read (%s): Close error", name() );
#endif
if ( d->rsn )
d->rsn->setEnabled( FALSE );
@@ -1272,7 +1272,7 @@ void QSocket::sn_read( bool force )
} else { // data to be read
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): sn_read: %ld incoming bytes", name(), nbytes );
+ tqDebug( "QSocket (%s): sn_read: %ld incoming bytes", name(), nbytes );
#endif
if ( nbytes > (int)sizeof(buf) ) {
// big
@@ -1289,7 +1289,7 @@ void QSocket::sn_read( bool force )
}
if ( nread == 0 ) {
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): sn_read: Connection closed", name() );
+ tqDebug( "QSocket (%s): sn_read: Connection closed", name() );
#endif
// ### we should rather ask the socket device if it is closed
d->connectionClosed();
@@ -1306,7 +1306,7 @@ void QSocket::sn_read( bool force )
return;
}
#if defined(QT_CHECK_RANGE)
- qWarning( "QSocket::sn_read: Read error" );
+ tqWarning( "QSocket::sn_read: Read error" );
#endif
if ( d->rsn )
d->rsn->setEnabled( FALSE );
@@ -1316,7 +1316,7 @@ void QSocket::sn_read( bool force )
}
if ( nread != (int)a->size() ) { // unexpected
#if defined(CHECK_RANGE) && !defined(Q_OS_WIN32)
- qWarning( "QSocket::sn_read: Unexpected short read" );
+ tqWarning( "QSocket::sn_read: Unexpected short read" );
#endif
a->resize( nread );
}
@@ -1356,7 +1356,7 @@ void QSocket::tryConnection()
if ( d->socket->connect( d->addr, d->port ) ) {
d->state = Connected;
#if defined(QSOCKET_DEBUG)
- qDebug( "QSocket (%s): sn_write: Got connection to %s",
+ tqDebug( "QSocket (%s): sn_write: Got connection to %s",
name(), peerName().ascii() );
#endif
if ( d->rsn )
diff --git a/src/network/qsocketdevice.cpp b/src/network/qsocketdevice.cpp
index f298cff..5a5bfab 100644
--- a/src/network/qsocketdevice.cpp
+++ b/src/network/qsocketdevice.cpp
@@ -163,7 +163,7 @@ QSocketDevice::QSocketDevice( int socket, Type type )
d(new QSocketDevicePrivate(Unknown))
{
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice: Created QSocketDevice %p (socket %x, type %d)",
+ tqDebug( "QSocketDevice: Created QSocketDevice %p (socket %x, type %d)",
this, socket, type );
#endif
init();
@@ -186,7 +186,7 @@ QSocketDevice::QSocketDevice( Type type )
d(new QSocketDevicePrivate(IPv4))
{
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice: Created QSocketDevice object %p, type %d",
+ tqDebug( "QSocketDevice: Created QSocketDevice object %p, type %d",
this, type );
#endif
init();
@@ -215,7 +215,7 @@ QSocketDevice::QSocketDevice( Type type, Protocol protocol, int )
d(new QSocketDevicePrivate(protocol))
{
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice: Created QSocketDevice object %p, type %d",
+ tqDebug( "QSocketDevice: Created QSocketDevice object %p, type %d",
this, type );
#endif
init();
@@ -231,7 +231,7 @@ QSocketDevice::~QSocketDevice()
delete d;
d = 0;
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice: Destroyed QSocketDevice %p", this );
+ tqDebug( "QSocketDevice: Destroyed QSocketDevice %p", this );
#endif
}
@@ -308,7 +308,7 @@ void QSocketDevice::setSocket( int socket, Type type )
if ( fd != -1 ) // close any open socket
close();
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice::setSocket: socket %x, type %d", socket, type );
+ tqDebug( "QSocketDevice::setSocket: socket %x, type %d", socket, type );
#endif
t = type;
fd = socket;
@@ -335,7 +335,7 @@ bool QSocketDevice::open( int mode )
if ( isOpen() || !isValid() )
return FALSE;
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice::open: mode %x", mode );
+ tqDebug( "QSocketDevice::open: mode %x", mode );
#endif
setMode( mode & IO_ReadWrite );
setState( IO_Open );
diff --git a/src/network/qsocketdevice_unix.cpp b/src/network/qsocketdevice_unix.cpp
index d773a0d..81f21c8 100644
--- a/src/network/qsocketdevice_unix.cpp
+++ b/src/network/qsocketdevice_unix.cpp
@@ -224,7 +224,7 @@ void QSocketDevice::close()
setState( 0 );
::close( fd );
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice::close: Closed socket %x", fd );
+ tqDebug( "QSocketDevice::close: Closed socket %x", fd );
#endif
fd = -1;
fetchConnectionParameters();
@@ -268,7 +268,7 @@ bool QSocketDevice::blocking() const
void QSocketDevice::setBlocking( bool enable )
{
#if defined(QSOCKETDEVICE_DEBUG)
- qDebug( "QSocketDevice::setBlocking( %d )", enable );
+ tqDebug( "QSocketDevice::setBlocking( %d )", enable );
#endif
if ( !isValid() )
return;
@@ -760,20 +760,20 @@ Q_LONG QSocketDevice::readBlock( char *data, Q_ULONG maxlen )
{
#if defined(QT_CHECK_NULL)
if ( data == 0 && maxlen != 0 ) {
- qWarning( "QSocketDevice::readBlock: Null pointer error" );
+ tqWarning( "QSocketDevice::readBlock: Null pointer error" );
}
#endif
#if defined(QT_CHECK_STATE)
if ( !isValid() ) {
- qWarning( "QSocketDevice::readBlock: Invalid socket" );
+ tqWarning( "QSocketDevice::readBlock: Invalid socket" );
return -1;
}
if ( !isOpen() ) {
- qWarning( "QSocketDevice::readBlock: Device is not open" );
+ tqWarning( "QSocketDevice::readBlock: Device is not open" );
return -1;
}
if ( !isReadable() ) {
- qWarning( "QSocketDevice::readBlock: Read operation not permitted" );
+ tqWarning( "QSocketDevice::readBlock: Read operation not permitted" );
return -1;
}
#endif
@@ -851,25 +851,25 @@ Q_LONG QSocketDevice::writeBlock( const char *data, Q_ULONG len )
{
if ( data == 0 && len != 0 ) {
#if defined(QT_CHECK_NULL) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::writeBlock: Null pointer error" );
+ tqWarning( "QSocketDevice::writeBlock: Null pointer error" );
#endif
return -1;
}
if ( !isValid() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::writeBlock: Invalid socket" );
+ tqWarning( "QSocketDevice::writeBlock: Invalid socket" );
#endif
return -1;
}
if ( !isOpen() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::writeBlock: Device is not open" );
+ tqWarning( "QSocketDevice::writeBlock: Device is not open" );
#endif
return -1;
}
if ( !isWritable() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::writeBlock: Write operation not permitted" );
+ tqWarning( "QSocketDevice::writeBlock: Write operation not permitted" );
#endif
return -1;
}
@@ -939,32 +939,32 @@ Q_LONG QSocketDevice::writeBlock( const char * data, Q_ULONG len,
{
if ( t != Datagram ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::sendBlock: Not datagram" );
+ tqWarning( "QSocketDevice::sendBlock: Not datagram" );
#endif
return -1; // for now - later we can do t/tcp
}
if ( data == 0 && len != 0 ) {
#if defined(QT_CHECK_NULL) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::sendBlock: Null pointer error" );
+ tqWarning( "QSocketDevice::sendBlock: Null pointer error" );
#endif
return -1;
}
if ( !isValid() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::sendBlock: Invalid socket" );
+ tqWarning( "QSocketDevice::sendBlock: Invalid socket" );
#endif
return -1;
}
if ( !isOpen() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::sendBlock: Device is not open" );
+ tqWarning( "QSocketDevice::sendBlock: Device is not open" );
#endif
return -1;
}
if ( !isWritable() ) {
#if defined(QT_CHECK_STATE) || defined(QSOCKETDEVICE_DEBUG)
- qWarning( "QSocketDevice::sendBlock: Write operation not permitted" );
+ tqWarning( "QSocketDevice::sendBlock: Write operation not permitted" );
#endif
return -1;
}
diff --git a/src/network/qnetwork.cpp b/src/network/qnetwork.cpp
index 2d5ce00..0c4275b 100644
--- a/src/network/qnetwork.cpp
+++ b/src/network/qnetwork.cpp
@@ -1,6 +1,6 @@
/****************************************************************************
**
** Implementation of qInitNetworkProtocols function.
**
** Created : 970521
**
@@ -58,7 +58,7 @@
This function is declared in \l qnetwork.h.
*/
-void qInitNetworkProtocols()
+void tqInitNetworkProtocols()
{
#ifndef QT_NO_NETWORKPROTOCOL_FTP
QNetworkProtocol::registerNetworkProtocol( "ftp", new QNetworkProtocolFactory< QFtp > );
@@ -1,6 +1,6 @@
/****************************************************************************
**
-** Implementation of qInitNetworkProtocols function.
+** Implementation of tqInitNetworkProtocols function.
**
** Created : 970521
diff --git a/src/network/qnetwork.h b/src/network/qnetwork.h
index 649c01e..0fdc5b5 100644
--- a/src/network/qnetwork.h
+++ b/src/network/qnetwork.h
@@ -1,6 +1,6 @@
/****************************************************************************
**
** Definition of qInitNetworkProtocols function.
**
** Created : 970521
**
@@ -53,7 +53,7 @@
#ifndef QT_NO_NETWORK
-QM_EXPORT_NETWORK void qInitNetworkProtocols();
+QM_EXPORT_NETWORK void tqInitNetworkProtocols();
#endif
@@ -1,6 +1,6 @@
/****************************************************************************
**
-** Definition of qInitNetworkProtocols function.
+** Definition of tqInitNetworkProtocols function.
**
** Created : 970521